PyKEEN
======
.. automodule:: pykeen

.. toctree::
   :caption: Getting Started
   :name: quickstart
   :maxdepth: 2

   installation
   tutorial/first_steps
   tutorial/understanding_evaluation
   tutorial/translational_toy_example
   tutorial/running_hpo
   tutorial/running_ablation
   tutorial/byod
   tutorial/trackers/index
   tutorial/making_predictions
   tutorial/performance

.. toctree::
   :caption: Reference
   :name: reference
   :maxdepth: 2

   reference/pipeline
   reference/models
   reference/datasets
   reference/triples
   reference/training
   reference/stoppers
   reference/losses
   reference/regularizers
   reference/trackers
   reference/evaluation/index
   reference/negative_sampling
   reference/hpo
   reference/ablation
   reference/lookup
   reference/sealant

.. toctree::
   :caption: Appendix
   :name: appendix
   :maxdepth: 2

   references

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
